==> kbibtex_0.2.orig.tar.gz: kbibtex-0.2/src/fileimporterbibutils.h <==
/***************************************************************************
 *   Copyright (C) 2004-2005 by Thomas Fischer                             *
 *   fischer@unix-ag.uni-kl.de                                             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#ifdef HAVE_LIBBIBUTILS
#ifndef BIBTEXFILEIMPORTBIBUTILS_H
#define BIBTEXFILEIMPORTBIBUTILS_H

#include <bibutils.h>
#include <fileimporter.h>

namespace BibTeX
{

    /**
     @author Thomas Fischer <fischer@unix-ag.uni-kl.de>
    */
    class FileImporterBibUtils : public FileImporter
    {
    public:
        enum InputFormat {ifRIS = BIBL_RISIN, ifMedLine = BIBL_MEDLINEIN, ifISI = BIBL_ISIIN, ifEndNote = BIBL_ENDNOTEIN, ifCOPAC = BIBL_COPACIN};

        FileImporterBibUtils( InputFormat inputFormat );
        ~FileImporterBibUtils();

        File* load( QIODevice *iodevice );
        static bool guessCanDecode( const QString & text );

    public slots:
        void cancel();

    private:
        bool m_cancelFlag;
        QString m_workingDir;
        InputFormat m_inputFormat;
        FileImporterBibTeX *m_bibTeXImporter;

        QString createTempDir();
        void deleteTempDir( const QString& directory );

    };

}

#endif // BIBTEXFILEIMPORTBIBUTILS_H
#endif // HAVE_LIBBIBUTILS

==> kbibtex_0.2.1.orig.tar.gz: kbibtex-0.2.1/src/fileimporterbibutils.h <==
/***************************************************************************
 *   Copyright (C) 2004-2005 by Thomas Fischer                             *
 *   fischer@unix-ag.uni-kl.de                                             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#ifdef HAVE_LIBBIBUTILS
#ifndef BIBTEXFILEIMPORTBIBUTILS_H
#define BIBTEXFILEIMPORTBIBUTILS_H

#include <bibutils.h>
#include <fileimporter.h>
#include <fileimporterbibtex.h>

namespace BibTeX
{

    /**
     @author Thomas Fischer <fischer@unix-ag.uni-kl.de>
    */
    class FileImporterBibUtils : public FileImporter
    {
    public:
        enum InputFormat {ifRIS = BIBL_RISIN, ifMedLine = BIBL_MEDLINEIN, ifISI = BIBL_ISIIN, ifEndNote = BIBL_ENDNOTEIN, ifCOPAC = BIBL_COPACIN, ifUndefined = -9999};

        FileImporterBibUtils( InputFormat inputFormat );
        ~FileImporterBibUtils();

        File* load( QIODevice *iodevice );
        static bool guessCanDecode( const QString & text );
        static InputFormat guessInputFormat( const QString &text );

    public slots:
        void cancel();

    private:
        bool m_cancelFlag;
        QString m_workingDir;
        InputFormat m_inputFormat;
        FileImporterBibTeX *m_bibTeXImporter;

        QString createTempDir();
        void deleteTempDir( const QString& directory );

    };

}

#endif // BIBTEXFILEIMPORTBIBUTILS_H
#endif // HAVE_LIBBIBUTILS
